/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.jackrabbit.vfs.ext;

import org.apache.jackrabbit.vfs.ext.ds.TestVFSDataStore;
import org.apache.jackrabbit.vfs.ext.fs.VFSFileSystemTest;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;

/**
 * Test suite that includes all test cases for the this module.
 */
public class TestAll extends TestCase {

    /**
     * <code>TestAll</code> suite that executes all tests inside this module.
     */
    public static Test suite() {
        TestSuite suite = new TestSuite("VFS tests");
        suite.addTestSuite(TestVFSDataStore.class);
        suite.addTestSuite(VFSFileSystemTest.class);
        return suite;
    }
}
